GlobalConst class

Name: global_const.dart

Created by Static4u Date : 2023/4/12 15:17

Constructors

GlobalConst()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

baseAssetsPrefix → const String
defaultAvatarImg → const String
defaultErrorImg → const String
defaultPlaceholderImg → const String
packageName → const String
regexpStrChar → const String
regexpStrEmail → const String
regexpStrNumber → const String
数字正则